This is an automated email from the ASF dual-hosted git repository.
ibzib pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/beam.git
The following commit(s) were added to refs/heads/master by this push:
new 973752b07ad Nit: correct description for precommit cron jobs.
new f7be5ae5a47 Merge pull request #17276 from ibzib/job-description
973752b07ad is described below
commit 973752b07ad95847375b1731289d08c73ed20047
Author: Kyle Weaver <[email protected]>
AuthorDate: Mon Apr 4 16:39:10 2022 -0700
Nit: correct description for precommit cron jobs.
The default setting runs each job every 6 hours.
---
.test-infra/jenkins/PrecommitJobBuilder.groovy | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/.test-infra/jenkins/PrecommitJobBuilder.groovy
b/.test-infra/jenkins/PrecommitJobBuilder.groovy
index df2ef22d193..5a0df8eae89 100644
--- a/.test-infra/jenkins/PrecommitJobBuilder.groovy
+++ b/.test-infra/jenkins/PrecommitJobBuilder.groovy
@@ -57,11 +57,11 @@ class PrecommitJobBuilder {
definePhraseJob additionalCustomization
}
/** Create a pre-commit job which runs on a daily schedule. */
private void defineCronJob(Closure additionalCustomization) {
def job = createBaseJob 'Cron'
job.with {
- description buildDescription('on a daily schedule.')
+ description buildDescription('on a regular schedule.')
commonJobProperties.setAutoJob delegate
}
job.with additionalCustomization
@@ -57,11 +57,11 @@ class PrecommitJobBuilder {
definePhraseJob additionalCustomization
}
- /** Create a pre-commit job which runs on a daily schedule. */
+ /** Create a pre-commit job which runs on a regular schedule. */
private void defineCronJob(Closure additionalCustomization) {
def job = createBaseJob 'Cron'